@@ -1,39 +1,35 @@
 use crate::api::ApiClient;
+use crate::util::fail;
 use std::fs::{canonicalize, read_to_string, OpenOptions};
 use std::io::{ErrorKind, Write};
-use std::process::exit;
 
 pub async fn sign<'a>(client: &ApiClient, role: String, key: String, output: String) {
     // Convert relative to absolute path and ensure exists
     let path = match canonicalize(&key) {
         Ok(path) => path,
-        Err(e) => {
-            match e.kind() {
-                ErrorKind::NotFound => println!("Key '{}' does not exist", key),
-                _ => println!("Failed to convert relative to absolute path: {}", e),
-            }
-            exit(1);
-        }
+        Err(e) => match e.kind() {
+            ErrorKind::NotFound => fail(&format!("Key '{}' does not exist", key)),
+            _ => fail(&format!(
+                "Failed to convert relative to absolute path: {}",
+                e
+            )),
+        },
     };
 
     // Read file
     let contents = match read_to_string(path) {
         Ok(contents) => contents,
-        Err(e) => {
-            println!("Failed to read public key: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to read public key: {}", e)),
     };
 
     // Sign the public key
     let signed = match client.sign(role.to_string(), contents).await {
         Ok(signed) => signed,
-        Err(e) => {
-            println!("Failed to sign public key: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to sign public key: {}", e)),
     };
 
+    leg::success("Signed public key with role", None, None);
+
     // Output to stdout if no file
     if output == "" {
         println!("{}", signed);
@@ -45,22 +41,22 @@ pub async fn sign<'a>(client: &ApiClient, role: String, key: String, output: Str
         Err(e) => {
             match e.kind() {
                 ErrorKind::PermissionDenied => {
-                    println!("Cannot write signed public key: permission denied")
+                    fail("Cannot write signed public key: permission denied")
                 }
-                _ => println!("Failed to open output file: {}", e),
+                _ => fail(&format!("Failed to open output file: {}", e)),
             };
-            exit(1);
         }
     };
 
     // Write to file
     match file.write_all(signed.as_bytes()) {
         Ok(_) => {}
-        Err(e) => {
-            println!("Failed to write to output file: {}", e);
-            exit(1);
-        }
+        Err(e) => fail(&format!("Failed to write to output file: {}", e)),
     };
 
-    println!("Wrote signed public key to: {}", output);
+    leg::success(
+        &format!("Wrote signed public key to: {}", output),
+        None,
+        None,
+    );
 }
